ProSHADE: src/python/pyProSHADE_distances.cpp Source File

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

pyProSHADE_distances.cpp
1
21 //==================================================== Include PyBind11 header
22 #include <pybind11/pybind11.h>
23 #include <pybind11/stl.h>
24 #include <pybind11/numpy.h>
25
26 //==================================================== Add the ProSHADE_settings and ProSHADE_run classes to the PyBind11 module
27 void add_distancesClass ( pybind11::module& pyProSHADE )
28 {
29 pyProSHADE.def ( "computeEnergyLevelsDescriptor", &ProSHADE_internal_distances::computeEnergyLevelsDescriptor, "This function computes the energy levels descriptor value between two objects.", pybind11::arg ( "obj1" ), pybind11::arg ( "obj2" ), pybind11::arg ( "settings" ) );
30 pyProSHADE.def ( "computeTraceSigmaDescriptor", &ProSHADE_internal_distances::computeTraceSigmaDescriptor, "This function computes the trace sigma descriptor value between two objects.", pybind11::arg ( "obj1" ), pybind11::arg ( "obj2" ), pybind11::arg ( "settings" ) );
31 pyProSHADE.def ( "computeRotationunctionDescriptor", &ProSHADE_internal_distances::computeRotationunctionDescriptor, "This function computes the rotation function descriptor value between two objects.", pybind11::arg ( "obj1" ), pybind11::arg ( "obj2" ), pybind11::arg ( "settings" ) );
32 }
ProSHADE_internal_distances::computeRotationunctionDescriptor
proshade_double computeRotationunctionDescriptor(ProSHADE_internal_data::ProSHADE_data *obj1, ProSHADE_internal_data::ProSHADE_data *obj2, ProSHADE_settings *settings)
This function computes the rotation function descriptor value between two objects.
Definition: ProSHADE_distances.cpp:911
ProSHADE_internal_distances::computeTraceSigmaDescriptor
proshade_double computeTraceSigmaDescriptor(ProSHADE_internal_data::ProSHADE_data *obj1, ProSHADE_internal_data::ProSHADE_data *obj2, ProSHADE_settings *settings)
This function computes the trace sigma descriptor value between two objects.
Definition: ProSHADE_distances.cpp:621
ProSHADE_internal_distances::computeEnergyLevelsDescriptor
proshade_double computeEnergyLevelsDescriptor(ProSHADE_internal_data::ProSHADE_data *obj1, ProSHADE_internal_data::ProSHADE_data *obj2, ProSHADE_settings *settings)
This function computes the energy levels descriptor value between two objects.
Definition: ProSHADE_distances.cpp:165